<template>
	<div v-if="isMobileNav">
		<swiper :options="swiperNav" ref="mainNavSwiper">
			<swiper-slide>
				<ul class="main-nav">
					<li
						v-for="(item, index) in menu"
						:class="[
							item.class,
							{ containsSubs: !(item.children && item.children.length > 0) },
						]"
						:key="item.label"
					>
						<a
							v-html="item.label"
							:rel="linkRel(item.noFollow, item.noReferrer)"
							v-if="item.children && item.children.length > 0"
							@click="mobileLinkClicked(1, index)"
						></a>
						<a
							v-html="item.label"
							:rel="linkRel(item.noFollow, item.noReferrer)"
							v-else
							:href="item.url"
						></a>
					</li>
				</ul>
			</swiper-slide>
			<swiper-slide>
				<ul class="main-nav">
					<li class="prev" @click="mobilePrevClicked()">
						<a>{{ translations.previous }}</a>
					</li>
					<li class="containsSubs">
						<!-- All In -->
						<a
							v-if="
								typeof activeSubmenu.allInTitle != 'undefined' &&
								activeSubmenu.allInTitle.length > 0
							"
							v-html="activeSubmenu.allInTitle"
							:href="activeSubmenu.url"
							class="font-weight-bold"
							:rel="linkRel(activeSubmenu.noFollow, activeSubmenu.noReferrer)"
						></a>
						<a
							v-else
							v-html="translations.allIn + ' ' + activeSubmenu.label"
							:href="activeSubmenu.url"
							class="font-weight-bold"
							:rel="linkRel(activeSubmenu.noFollow, activeSubmenu.noReferrer)"
						></a>
					</li>
					<li
						v-for="(child, index) in activeSubmenu.children"
						:class="[
							child.class,
							{ containsSubs: !(child.children && child.children.length > 0) },
						]"
						:key="child.label"
						v-if="child.menu_type != 'widget'"
					>
						<a
							v-html="child.label"
							v-if="child.children && child.children.length > 0"
							@click="mobileLinkClicked(2, index)"
							:rel="linkRel(child.noFollow, child.noReferrer)"
						></a>
						<a
							v-html="child.label"
							v-else
							:href="child.url"
							:rel="linkRel(child.noFollow, child.noReferrer)"
						></a>
					</li>
				</ul>
			</swiper-slide>
			<swiper-slide
				v-if="activeSubmenu.children && activeSubmenu.children.length > 0"
			>
				<ul class="main-nav">
					<li class="prev" @click="mobilePrevClicked()">
						<a>{{ translations.previous }}</a>
					</li>
					<li class="containsSubs">
						<a
							v-if="
								typeof activeSubSubmenu.allInTitle != 'undefined' &&
								activeSubSubmenu.allInTitle.length > 0
							"
							class="font-weight-bold"
							v-html="activeSubSubmenu.allInTitle"
							:href="activeSubSubmenu.url"
							:rel="
								linkRel(activeSubSubmenu.noFollow, activeSubSubmenu.noReferrer)
							"
						></a>
						<a
							v-else
							class="font-weight-bold"
							v-html="translations.allIn + ' ' + activeSubSubmenu.label"
							:href="activeSubSubmenu.url"
							:rel="
								linkRel(activeSubSubmenu.noFollow, activeSubSubmenu.noReferrer)
							"
						></a>
					</li>
					<li
						v-for="grandchild in activeSubSubmenu.children"
						:class="[
							grandchild.class,
							{
								containsSubs: !(
									grandchild.children && grandchild.children.length > 0
								),
							},
						]"
						:key="grandchild.label"
						v-if="grandchild.menu_type != 'widget'"
					>
						<a
							v-html="grandchild.label"
							:href="grandchild.url"
							:rel="linkRel(grandchild.noFollow, grandchild.noReferrer)"
						></a>
					</li>
				</ul>
			</swiper-slide>
		</swiper>
	</div>
	<div v-else class="w-100">
		<div class="container">
			<ul class="main-nav" v-lazy-container="{ selector: 'img' }">
				<li
					v-for="item in menuItems"
					:key="item.label"
					:class="[
						item.class,
						{ containsSubs: item.children && item.children.length > 0 },
					]"
				>
					<template v-if="isTouchDevice">{{ item.label }}</template>
					<a
						v-else
						:href="item.url"
						v-html="item.label"
						:rel="linkRel(item.noFollow, item.noReferrer)"
					></a>
					<template v-if="item.class != 'mega-sub'">
						<div
							v-if="item.children && item.children.length > 0"
							class="mega-menu"
							:class="'column-' + item.columns"
						>
							<div
								v-for="child in item.children"
								v-if="child.menu_type == 'widget'"
								class="mega-widget"
								v-html="child.html"
								:key="child.html"
							></div>
							<ul>
								<li
									v-for="child in item.children"
									v-if="child.menu_type != 'widget'"
									:class="child.class"
									:key="child.label"
								>
									<a
										:rel="linkRel(child.noFollow, child.noReferrer)"
										:href="child.url"
										v-html="child.label"
									></a>
									<template>
										<ul v-if="child.children">
											<li
												v-for="grandChild in child.children"
												:class="grandChild.class"
												:key="grandChild.label"
											>
												<a
													:rel="
														linkRel(grandChild.noFollow, grandChild.noReferrer)
													"
													:href="grandChild.url"
													v-html="grandChild.label"
												></a>
											</li>
										</ul>
									</template>
								</li>
							</ul>
						</div>
					</template>
					<template v-else>
						<ul
							:class="item.class"
							v-if="item.children && item.children.length > 0"
						>
							<li
								v-for="child in item.children"
								:class="child.class"
								:key="child.label"
							>
								<a
									:rel="linkRel(child.noFollow, child.noReferrer)"
									:href="child.url"
									v-html="child.label"
								></a>
							</li>
						</ul>
					</template>
				</li>
				<li v-if="highLightedMenuItems.length" class="highlighted-nav">
					<span
						v-for="item in highLightedMenuItems"
						:key="item.label"
						:class="[
							item.class,
							{ containsSubs: item.children && item.children.length > 0 },
						]"
					>
						<template v-if="isTouchDevice">{{ item.label }}</template>
						<a
							v-else
							v-html="item.label"
							:href="item.url"
							:rel="linkRel(item.noFollow, item.noReferrer)"
						></a>
						<template v-if="item.class != 'mega-sub'">
							<div
								v-if="item.children && item.children.length > 0"
								class="mega-menu"
								:class="'column-' + item.columns"
							>
								<div
									v-for="child in item.children"
									v-if="child.menu_type == 'widget'"
									class="mega-widget"
									v-html="child.html"
									:key="child.html"
								></div>
								<ul>
									<li
										v-for="child in item.children"
										v-if="child.menu_type != 'widget'"
										:class="child.class"
										:key="child.label"
									>
										<a
											:rel="linkRel(child.noFollow, child.noReferrer)"
											:href="child.url"
											v-html="child.label"
										></a>
										<template>
											<ul v-if="child.children">
												<li
													v-for="grandChild in child.children"
													:class="grandChild.class"
													:key="grandChild.label"
												>
													<a
														:rel="
															linkRel(
																grandChild.noFollow,
																grandChild.noReferrer
															)
														"
														:href="grandChild.url"
														v-html="grandChild.label"
													></a>
												</li>
											</ul>
										</template>
									</li>
								</ul>
							</div>
						</template>
						<template v-else>
							<ul
								:class="item.class"
								v-if="item.children && item.children.length > 0"
							>
								<li
									v-for="child in item.children"
									:class="child.class"
									:key="child.label"
								>
									<a
										:rel="linkRel(child.noFollow, child.noReferrer)"
										:href="child.url"
										v-html="child.label"
									></a>
								</li>
							</ul>
						</template>
					</span>
				</li>
			</ul>
		</div>
	</div>
</template>

<script>
	module.exports = {
		data() {
			return {
				highlightClasses: ["highlighted", "highlighted-2", "highlighted-3"],
				menu: this.navJson,
				submenuIndex: 0,
				subsubmenuIndex: 0,
				swiperNav: {
					direction: "horizontal",
					slidesPerView: 1,
					spaceBetween: 0,
					allowTouchMove: false,
					pagination: {
						el: ".swiper-pagination",
						type: "bullets",
						clickable: true,
					},
				},
			};
		},
		methods: {
			linkRel(noFollow, noReferrer) {
				let linkRels = "";

				if (noFollow) linkRels += "nofollow";
				if (noReferrer) linkRels += " noreferrer";

				return linkRels;
			},
			mobileLinkClicked(level, index) {
				if (level === 1) {
					this.submenuIndex = index;
				} else if (level === 2) {
					this.subsubmenuIndex = index;
				}

				this.$refs.mainNavSwiper.swiper.slideNext();
			},
			mobilePrevClicked() {
				this.subsubmenuIndex = 0;
				this.$refs.mainNavSwiper.swiper.slidePrev();
			},
		},
		store,
		props: {
			navJson: Array,
			screenWidth: String,
			translations: Object,
		},
		computed: {
			activeSubmenu() {
				return this.menu[this.submenuIndex];
			},
			activeSubSubmenu() {
				return this.activeSubmenu.children[this.subsubmenuIndex];
			},
			highLightedMenuItems() {
				return this.menu.filter(item =>
					this.highlightClasses.includes(item.class)
				);
			},
			isMobileNav() {
				return ["xs", "sm", "md"].includes(this.screenWidth);
			},
			isTouchDevice() {
				return this.$store.getters.getIsTouchDevice;
			},
			menuItems() {
				return this.menu.filter(
					item => !this.highlightClasses.includes(item.class)
				);
			},
		},
	};
</script>
